@@ -101,14 +101,13 @@ def cached_method(func: Callable):
     """
     Decorator to cache method return values
     """
-    null = object()
 
     @wraps(func)
     def cached_fn(self, *args):
         if getattr(self, '__cache__', None) is None:
             setattr(self, '__cache__', {})
-        value = self.__cache__.get(args, null)
-        if value is null:
+        value = self.__cache__.get(args, ...)
+        if value is Ellipsis:
             value = func(self, *args)
             self.__cache__[args] = value
         return value
@@ -121,12 +120,11 @@ def cached_classmethod(func: Callable):
     Decorator to cache classmethod return values
     """
     cache = {}
-    null = object()
 
     @wraps(func)
     def cached_fn(cls, *args):
-        value = cache.get(args, null)
-        if value is null:
+        value = cache.get(args, ...)
+        if value is Ellipsis:
             value = func(cls, *args)
             cache[args] = value
         return value
